@@ -50,6 +50,11 @@
 #include "as_gui.h"             // Main classes
 #include "as_amount.h"          // AmountBox class
 #include "as_user.h"            // User class
+#include "as_const.h"           // Application constants
+#include "as_table.h"           // Class TiTable
+#include "as_pref.h"            // Class Preferences
+#include "as_panel.h"           // Class Prefpanel
+#include "as_datedit.h"         // Class Daydateedit
 
 // Icon pixel maps
 #include "as_gfx/filenew.xpm"   // static const char *s_kpcFilenew_xpm[]
@@ -401,7 +406,6 @@ void Titraqform::setupMenubar(void)
     m_pTbarspopup->setItemChecked(nMenuid, true);
     nMenuid = m_pTbarspopup->insertItem(trUtf8("&Whats"), this, SLOT(showWhatsbar()));
     m_pTbarspopup->setItemChecked(nMenuid, true);
-    m_pViewpopup->insertSeparator();
     m_pViewpopup->insertItem(trUtf8("&Columns"), m_pColspopup);
     nMenuid = m_pColspopup->insertItem(trUtf8("&Status"), this, SLOT(showStatcol()));
     m_pColspopup->setItemChecked(nMenuid, true);
@@ -497,6 +501,7 @@ void Titraqform::setupToolbars(void)
     m_pViewtools->setOpaqueMoving(false);
     m_pViewtools->setCloseMode(QDockWindow::Never);
     m_pRefreshact->addTo(m_pViewtools);
+    m_pSyncact->addTo(m_pViewtools);
 
     // Construct and populate the lonely whatsthis tool bar
     m_pWhatstools = new QToolBar("Toolwhats", this, DockTop);
