@@ -40,9 +40,11 @@
 
 // User interface
 #include "as_gui.h"             // Main classes
+#include "as_const.h"           // Application constants
 #include "as_tableitem.h"       // For class RtTableItem
 #include "as_crc.h"             // For quality strings
 #include "as_uuid.h"            // UUID classes
+#include "as_table.h"           // TiTable class
 
 // Icon pixel maps
 #include "as_gfx/statok.xpm"    // static const char *s_kpcStatokay_xpm[]
