@@ -53,17 +53,19 @@
 #endif
 
 #include "as_except.h"  // Exception classes
-#include "as_const.h"   // For general constants
-#include "as_pref.h"    // For class Preferences
-#include "as_amount.h"  // For class AmountBox
-#include "as_table.h"   // For class TiTable
-#include "as_datedit.h" // For class Daydatedit
 
 // Version information
 #define _AS_VERSION_CPP_AS_HEADER_
 #include "as_version.cpp"
 #undef  _AS_VERSION_CPP_AS_HEADER_
 
+// Method prototypes
+// class AmountBox; // Warning: Might be replaced with QTimeEdit
+class Daydatedit;
+class TiTable;
+class Preferences;
+class Prefpanel;
+
 // Intentional no operation
 #define TITRAQ_NOP ((void)0)
 
@@ -290,6 +292,8 @@ protected slots:
     void showRemarkcol(void);           // View menu show Remarks column
     void genReport(void);               // Generate a local formatted report
     void savePrefs(void);               // Save user preferences
+    void applyPrefs(void);              // Apply preferences from applied()
+    void applyPrefs(Prefpanel *);       // Apply preferences from accept()
 
 protected:
     // Application main events
