@@ -208,11 +208,11 @@ Prefpanel::Prefpanel(QWidget *pParent, const char *kszName, bool bModal, WFlags
     m_pVlayout->addLayout(m_pButtlay);
 
     // Connect our signals to slots, accept() and reject() are Qt implicit
-    connect(m_pOkaybutton, SIGNAL(clicked()), this, SLOT(accept()));
-    connect(m_pApplybutton, SIGNAL(clicked()), this, SLOT(apply()));
-    connect(m_pCancelbutton, SIGNAL(clicked()), this, SLOT(reject()));
-    connect(m_pCorbacheck, SIGNAL(toggled(bool)), this, SLOT(enableCorba(bool)));
-    connect(m_pSoapcheck, SIGNAL(toggled(bool)), this, SLOT(enableSoap(bool)));
+    connect(m_pOkaybutton, SIGNAL(clicked(void)), SLOT(accept(void)));
+    connect(m_pApplybutton, SIGNAL(clicked(void)), SIGNAL(applied(void)));
+    connect(m_pCancelbutton, SIGNAL(clicked(void)), SLOT(reject(void)));
+    connect(m_pCorbacheck, SIGNAL(toggled(bool)), SLOT(enableCorba(bool)));
+    connect(m_pSoapcheck, SIGNAL(toggled(bool)), SLOT(enableSoap(bool)));
     this->textChange();
     this->resize(QSize(400, 264).expandedTo(minimumSizeHint()));
 }
@@ -272,12 +272,3 @@ void Prefpanel::textChange()
 //    QToolTip::add(m_pSwitchgroup, tr("Tooltip for Switchbox", "Comment for toolTip Switchbox"));
 //    QWhatsThis::add(m_pSwitchgroup, tr("Whatsthis for Switchbutton", "Comment for whatsThis Switchbox"));
 }
-
-//
-// Applies changes user selected from this class
-//
-void Prefpanel::apply(void)
-{
-    Prototype Unimp;
-    Unimp.doMbox();
-}
