@@ -32,6 +32,8 @@
 #include <qheader.h>
 
 #include "as_gui.h"
+#include "as_const.h"
+#include "as_table.h"
 
 
 // Implements an event filter for catching header double click events
